!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!  Program   : s i c o g r a p h . F 9 0

!  Date      : 2008-12-17

!  Purpose   : Processing and graphical display (with GMT) of the output of
!              SICOPOLIS V2.9.

!! Copyright 2008 Ralf Greve
!!
!! This file is part of SICOPOLIS.
!!
!! SICOPOLIS is free software: you can redistribute it and/or modify
!! it under the terms of the GNU General Public License as published by
!! the Free Software Foundation, either version 3 of the License, or
!! (at your option) any later version.
!!
!! SICOPOLIS is distributed in the hope that it will be useful,
!! but WITHOUT ANY WARRANTY; without even the implied warranty of
!! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!! GNU General Public License for more details.
!!
!! You should have received a copy of the GNU General Public License
!! along with SICOPOLIS.  If not, see <http://www.gnu.org/licenses/>.

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!-------- Inclusion of specification header --------

#include "sico_specs.h"

!-------- Inclusion of global-variable module --------

#include "sicograph_variables.F90"

!-------- Compiler --------

#define INTEL   /* Options: INTEL, NAG, GFORTRAN, G95 */

!-------- Further settings --------

#define GMT_SCRIPT_SHELL 'tcsh'
#define GMT_SCRIPT_PATH './gmt_scripts'

!-------- Begin of main program --------

program sicograph

use sicograph_variables

#if defined(NAG)
use f90_unix_proc
    ! Required for executing shell commands with "call system('...')"
#endif

implicit none
integer iexit
integer :: menue=0
integer :: ndata
character (len=256) :: runname
character (len= 16) :: domain, topo_marker
character (len=  2) :: ergnum

#if ( defined(INTEL) )
interface
  integer function system(commanda)
  character (len=*) commanda
  end function system
end interface
#endif

#if defined(ANT)
   domain = 'ant'
   topo_marker = '_rb_'
#elif defined(EMTP2SGE)
   domain = 'emtp2sge'
   topo_marker = 'none'
#elif defined(GRL)
   domain = 'grl'
   topo_marker = '_bb_'
#elif defined(HEINO)
   domain = 'heino'
   topo_marker = 'none'
#elif defined(NHEM)
   domain = 'nhem'
   topo_marker = '_e5_'
#elif defined(NMARS)
   domain = 'nmars'
   topo_marker = 'none'
#elif defined(SCAND)
   domain = 'scand'
   topo_marker = '_e5_'
#elif defined(SMARS)
   domain = 'smars'
   topo_marker = 'none'
#elif defined(TIBET)
   domain = 'tibet'
   topo_marker = '_e2_'
#endif

runname = RUNNAME

!-------- Menue --------

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = system('clear')
#elif ( defined(NAG) )
call system('clear')
#endif

do

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plotting of SICOPOLIS results and data:'
   write(6,'(1x,a)') '---------------------------------------'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plan view:'
   write(6,'(1x,a)') '  (1) Ice-surface topography'
   write(6,'(1x,a)') '  (2) Ice thickness'
   write(6,'(1x,a)') '  (3) Basal topography'
   write(6,'(1x,a)') '  (5) Surface velocity'
   write(6,'(1x,a)') '  (6) Basal temperature (relative to pressure melting)'
   write(6,'(1x,a)') '  (7) Surface temperature'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plan view (data):'
   write(6,'(1x,a)') ' (11) Ice-surface topography'
   write(6,'(1x,a)') ' (12) Ice thickness'
   write(6,'(1x,a)') ' (13) Basal topography'
   write(6,'(1x,a)') ' (14) Equilibrated basal topography'
   write(6,'(1x,a)') ' (15) Precipitation rate'
   write(6,'(1x,a)') ' (16) LGM anomaly of precipitation rate'
   write(6,'(1x,a)') ' (17) Surface temperature'
   write(6,'(1x,a)') ' (18) LGM anomaly of surface temperature'
   write(6,'(1x,a)') ' (19) Geothermal heat flux'
   write(6,'(1x,a)') ' (20) Surface velocity'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') ' (22) (Simulated - measured) ice thickness'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Transect:'
   write(6,'(1x,a)') ' (31) along the x axis [not yet implemented!]'
   write(6,'(1x,a)') ' (32) along the y axis [not yet implemented!]'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Other:'
   write(6,'(1x,a)') ' (41) Time series'
#if defined(HEINO)
   write(6,'(1x,a)') ' (42) Time series for the sediment region'
#endif
#if ( defined(ANT) \
      || defined(EMTP2SGE) \
      || defined(GRL) \
      || defined(HEINO) \
      || defined(NMARS) )
   write(6,'(1x,a)') ' (43) Time series for ice cores / selected points'
#endif
   write(6,'(1x,a)') ' (44) Scatter plots'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') '  (0) Ende'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' > '
   read (5,*) menue

   if ((menue >= 1).and.(menue <= 30)) then
      call plan_view(domain, runname, topo_marker, menue)
      menue=0
   else if (menue == 41) then
      call time_series(domain, runname)
      menue=0
#if defined(HEINO)
   else if (menue == 42) then
      call time_series_sed(domain, runname)
      menue=0
#endif
#if ( defined(ANT) \
      || defined(EMTP2SGE) \
      || defined(GRL) \
      || defined(HEINO) \
      || defined(NMARS) )
   else if (menue == 43) then
      call time_series_core(domain, runname)
      menue=0
#endif
   else if (menue == 44) then
      call scatter_plot(domain, runname, topo_marker)
      menue=0
   end if

   if (menue == 0) exit

end do

write(6,'(1x,a)') ' '

end program sicograph

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  p l a n _ v i e w

!   Purpose    :  Plan-view plots (topography etc.).

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine plan_view(domain, runname, topo_marker, menue)

use sicograph_variables

#if defined(NAG)
use f90_unix_proc
    ! Required for executing shell commands with "call system('...')"
#endif

implicit none
integer :: i, j, n
integer :: iexit
integer :: ios
integer :: menue
integer :: i_cb_flag, i_cl_flag
integer, parameter :: n_unit=11
integer, dimension(0:IMAX,0:JMAX) :: maske_gr_sim
real, dimension(0:IMAX,0:JMAX) :: zs_gr_sim, zb_gr_sim, zb0_gr_sim, &
                                  H_c_gr_sim, H_t_gr_sim
real, dimension(0:IMAX,0:JMAX) :: data
real, parameter :: offset_topo=0.1, offset_thick=0.1, &
                   offset_vel=0.1, offset_temp=0.1, &
                   eps=1.0e-05
character (len=256) :: runname
character (len=256) :: para_file
character (len=256) :: x_min, x_max, x_stp, x_lbl, &
                       y_min, y_max, y_stp, y_lbl, &
                       lambda_min, lambda_max, lambda_stp, lambda_lbl, &
                       phi_min, phi_max, phi_stp, phi_lbl, &
                       dummy_lbl, &
                       lon_ctr, lat_ctr, &
                       lon_lol, lat_lol, lon_upr, lat_upr, &
                       lon_anot, lat_anot, lon_grid, lat_grid
character (len= 16) :: domain, topo_marker, &
                       ch_data, ch_data_unit, dx, dx_int, &
                       dlambda, dlambda_int, dphi, dphi_int, &
                       cb_flag, cl_flag
character (len=  2) :: ergnum

interface
  subroutine read_plot_par(n_unit, lbl, val1, val2, val3, val4, val5)
    implicit none
    integer n_unit
    character (len=256) :: lbl, val1
    character (len=256), optional :: val2, val3, val4, val5
    end subroutine read_plot_par
end interface

#if ( defined(INTEL) )
interface
  integer function system(commanda)
  character (len=*) commanda
  end function system
end interface
#endif

!-------- Grid spacing --------

#if ( (GRID ==0) || (GRID == 1) )

if (abs(DX-5.0).lt.eps) then
   dx =   '5.0'; dx_int =  '05'
else if (abs(DX-10.0).lt.eps) then
   dx =  '10.0'; dx_int =  '10'
else if (abs(DX-20.0).lt.eps) then
   dx =  '20.0'; dx_int =  '20'
else if (abs(DX-25.0).lt.eps) then
   dx =  '25.0'; dx_int =  '25'
else if (abs(DX-40.0).lt.eps) then
   dx =  '40.0'; dx_int =  '40'
else if (abs(DX-50.0).lt.eps) then
   dx =  '50.0'; dx_int =  '50'
else if (abs(DX-75.0).lt.eps) then
   dx =  '75.0'; dx_int =  '75'
else if (abs(DX-80.0).lt.eps) then
   dx =  '80.0'; dx_int =  '80'
else if (abs(DX-100.0).lt.eps) then
   dx = '100.0'; dx_int = '100'
else if (abs(DX-150.0).lt.eps) then
   dx = '150.0'; dx_int = '150'
else if (abs(DX-160.0).lt.eps) then
   dx = '160.0'; dx_int = '160'
else if (abs(DX-200.0).lt.eps) then
   dx = '200.0'; dx_int = '200'
else
   stop ' Grid spacing cannot be determined!'
end if

#elif (GRID==2)

if ( (abs(DLAMBDA-(1.0d0/3.0d0).lt.eps)) &
     .and. (abs(DPHI-(1.0d0/3.0d0).lt.eps)) ) then
   dlambda = '20.0'; dphi = '20.0';  dlambda_int = '20'; dphi_int = '20'
else if ( (abs(DLAMBDA-(1.0d0/6.0d0).lt.eps)) &
          .and. (abs(DPHI-(1.0d0/6.0d0).lt.eps)) ) then
   dlambda = '10.0'; dphi = '10.0';  dlambda_int = '10'; dphi_int = '10'
else if ( (abs(DLAMBDA-(1.0d0/12.0d0).lt.eps)) &
          .and. (abs(DPHI-(1.0d0/12.0d0).lt.eps)) ) then
   dlambda = '5.0'; dphi = '5.0';  dlambda_int = '05'; dphi_int = '05'
else
   stop ' Grid spacing cannot be determined!'
end if

#endif

!-------- Reading of time-slice data --------

if ((menue >= 1).and.(menue <= 10)) then
   call read_erg(runname, ergnum, menue)
end if

!-------- Reading of input data --------

if ((menue >= 11).and.(menue <= 20)) then

#if ( (GRID==0) || (GRID==1) )
   call read_data(domain, topo_marker, dx_int, menue)
#elif (GRID==2)
   call read_data(domain, topo_marker, dphi_int, menue)
#endif
   ergnum = 'da'
end if

!-------- Reading of time-slice and input data for difference plots --------

if ((menue >= 21).and.(menue <= 30)) then

   call read_erg(runname, ergnum, menue)

   zs_gr_sim    = zs_gr
   zb_gr_sim    = zb_gr
   zb0_gr_sim   = zb0_gr
   maske_gr_sim = maske_gr
   H_c_gr_sim   = H_c_gr
   H_t_gr_sim   = H_t_gr

#if ( (GRID==0) || (GRID==1) )
   call read_data(domain, topo_marker, dx_int, menue)
#elif (GRID==2)
   call read_data(domain, topo_marker, dphi_int, menue)
#endif

end if

!-------- Plotting of colour bar --------

write(6,'(1x,a)') ' '
write(6,'(1x,a)') 'Plot (1) with or (2) without colour bar?'
write(6,'(1x,a)') ' '
write(6,'(1x,a)',advance='no') ' > '
read (5,*) i_cb_flag

if (i_cb_flag == 1) then
   cb_flag = 'true'
else
   cb_flag = 'false'
end if

!-------- Plotting of contour labels --------

write(6,'(1x,a)') ' '
write(6,'(1x,a)') 'Plot (1) with or (2) without contour labels?'
! write(6,'(1x,a)') '(Will be overridden if settings are made in *.zzz file.)'
write(6,'(1x,a)') ' '
write(6,'(1x,a)',advance='no') ' > '
read (5,*) i_cl_flag

if (i_cl_flag == 1) then
   cl_flag = 'true'
else
   cl_flag = 'false'
end if

!-------- Writing of data on temporary file --------

!  ------ Quantity to be plotted

if ((menue==1).or.(menue==11)) then

   data         =  zs_gr
   ch_data      = 'zs'
   ch_data_unit = 'km'

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

   data = data - z_sl_gr   ! topography relative to sea level

   do i=0, IMAX
   do j=0, JMAX
      if (maske_gr(i,j) == 2) data(i,j) = min(data(i,j), -offset_topo)
   end do
   end do

#endif

else if ((menue==2).or.(menue==12)) then

   data         =  H_c_gr + H_t_gr
   ch_data      = 'H'
   ch_data_unit = 'km'

   do i=0, IMAX
   do j=0, JMAX
      if (maske_gr(i,j) /= 0) data(i,j) = -offset_thick
   end do
   end do

else if ((menue==3).or.(menue==13)) then

   data         =  zb_gr
   ch_data      = 'zb'
   ch_data_unit = 'km'

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

   data = data - z_sl_gr   ! topography relative to sea level

   do i=0, IMAX
   do j=0, JMAX
      if (maske_gr(i,j) == 2) data(i,j) = min(data(i,j), -offset_topo)
   end do
   end do
#endif

else if (menue==14) then

   data         =  zb0_gr
   ch_data      = 'zb0'
   ch_data_unit = 'km'

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

   data = data - z_sl_gr   ! topography relative to sea level

   do i=0, IMAX
   do j=0, JMAX
      if (maske_gr(i,j) == 2) data(i,j) = min(data(i,j), -offset_topo)
   end do
   end do

#endif

else if (menue==5) then

   do i=0, IMAX
   do j=0, JMAX
      if (maske_gr(i,j) == 0) then
         data(i,j) = sqrt( &
               0.25*(vx_c_gr(i,j,KCMAX)+vx_c_gr(i-1,j,KCMAX))**2 &
              +0.25*(vy_c_gr(i,j,KCMAX)+vy_c_gr(i,j-1,KCMAX))**2 )
      else
         data(i,j) = -offset_vel
      end if
   end do
   end do

   ch_data      = 'vs'

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

   ch_data_unit = 'm/a'

#else   /* Martian ice sheet */

   ch_data_unit = 'mm/a'

#endif

else if (menue==6) then

   do i=0, IMAX
   do j=0, JMAX

      data(i,j) = temph_c_gr(i,j,0)

/* #if ( defined(ANT) \                                    */
/*       || defined(GRL) \                                 */
/*       || defined(SCAND) \                               */
/*       || defined(NHEM) \                                */
/*       || defined(TIBET) \				   */
/*       || defined(EMTP2SGE) \                            */
/*       || defined(HEINO) )   terrestrial ice sheet       */

      if (maske_gr(i,j) /= 0)  data(i,j) = offset_temp
      if (n_cts_gr(i,j) /= -1) data(i,j) = offset_temp

/* #endif */

   end do
   end do

   ch_data      = 'Tbh'
   ch_data_unit = 'C'   ! 'deg\ C'

else if (menue==7) then

   do i=0, IMAX
   do j=0, JMAX
      data(i,j) = temp_c_gr(i,j,KCMAX)
   end do
   end do

   ch_data      = 'Ts'
   ch_data_unit = 'C'   ! 'deg\ C'

else if (menue==15) then

   data         =  precip_gr
   ch_data      = 'precip'
   ch_data_unit = 'mm\ w.e./a'

else if (menue==16) then

   data         =  precip_lgm_anom_gr
   ch_data      = 'precip_lgm_anom'
   ch_data_unit = '1'

else if (menue==17) then

   data         =  temp_s_gr
   ch_data      = 'temp_s'
   ch_data_unit = 'C'   ! 'deg\ C'

else if (menue==18) then

   data         =  temp_s_lgm_anom_gr
   ch_data      = 'temp_s_lgm_anom'
   ch_data_unit = 'C'   ! 'deg\ C'

else if (menue==19) then

   data         =  qgeo_gr
   ch_data      = 'qgeo'
   ch_data_unit = 'mW/m2'

else if (menue==20) then

   do i=0, IMAX
   do j=0, JMAX
      data(i,j) =  v_s_gr(i,j)
      if (data(i,j) < eps) data(i,j) = -offset_vel
   end do
   end do

   ch_data      = 'vs'

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

   ch_data_unit = 'm/a'

#else   /* Martian ice sheet */

   ch_data_unit = 'mm/a'

#endif

else if (menue==22) then

   data         = (H_c_gr_sim+H_t_gr_sim)-(H_c_gr+H_t_gr)
   data         = data * 1000.0   ! km -> m
   ch_data      = 'dH'
   ch_data_unit = 'm'

end if

open(n_unit, iostat=ios, &
     file=GMT_SCRIPT_PATH//'/tmp/' &
     //trim(runname)//trim(ergnum)//'_'//trim(ch_data)//'_tmp.erg', &
     status='replace')

do i=0, IMAX
do j=0, JMAX
   write(n_unit,'(3(1x,1pe10.3))') xi_gr(i), eta_gr(j), data(i,j)
end do
end do

close(n_unit, status='keep')

!  ------ Ice thickness (for plotting the ice margin)

data = H_c_gr + H_t_gr

do i=0, IMAX
do j=0, JMAX
   if (maske_gr(i,j) /= 0) data(i,j) = -offset_thick
end do
end do

open(n_unit, iostat=ios, &
     file=GMT_SCRIPT_PATH//'/tmp/' &
     //trim(runname)//trim(ergnum)//'_'//trim(ch_data)//'_tmp2.erg', &
     status='replace')

do i=0, IMAX
do j=0, JMAX
   write(n_unit,'(3(1x,1pe10.3))') xi_gr(i), eta_gr(j), data(i,j)
end do
end do

close(n_unit, status='keep')

!  ------ Surface topography (for plotting the h=0 contour)

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

data = zs_gr

data = data - z_sl_gr   ! topography relative to sea level

do i=0, IMAX
do j=0, JMAX
   if (maske_gr(i,j) == 2) data(i,j) = min(data(i,j), -offset_topo)
end do
end do

#else   /* Martian ice sheet */

data = -100.0   ! dummy

#endif

open(n_unit, iostat=ios, &
     file=GMT_SCRIPT_PATH//'/tmp/' &
     //trim(runname)//trim(ergnum)//'_'//trim(ch_data)//'_tmp3.erg', &
     status='replace')

do i=0, IMAX
do j=0, JMAX
   write(n_unit,'(3(1x,1pe10.3))') xi_gr(i), eta_gr(j), data(i,j)
end do
end do

close(n_unit, status='keep')

!-------- Reading of plot parameters --------

para_file = 'plan_view_'//trim(domain)//'.dat'

open(n_unit, iostat=ios, &
     file='parameter_files/'//trim(para_file), status='old')

if (ios == 0) then

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' available.'
   write(6,'(1x,a)') 'Parameters listed in this file used.'

#if ( (GRID==0) || (GRID==1) )
   call read_plot_par(n_unit, x_lbl, x_min, x_max, x_stp)
   call read_plot_par(n_unit, y_lbl, y_min, y_max, y_stp)
   call read_plot_par(n_unit, dummy_lbl, lon_ctr)
   call read_plot_par(n_unit, dummy_lbl, lat_ctr)
   call read_plot_par(n_unit, dummy_lbl, lon_lol)
   call read_plot_par(n_unit, dummy_lbl, lat_lol)
   call read_plot_par(n_unit, dummy_lbl, lon_upr)
   call read_plot_par(n_unit, dummy_lbl, lat_upr)
   call read_plot_par(n_unit, dummy_lbl, lon_anot)
   call read_plot_par(n_unit, dummy_lbl, lat_anot)
   call read_plot_par(n_unit, dummy_lbl, lon_grid)
   call read_plot_par(n_unit, dummy_lbl, lat_grid)
#elif (GRID==2)
   call read_plot_par(n_unit, lambda_lbl, lambda_min, lambda_max, lambda_stp)
   call read_plot_par(n_unit, phi_lbl, phi_min, phi_max, phi_stp)
#endif

else

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' not available.'
   write(6,'(1x,a)') 'Parameters will be computed automatically.'

#if ( (GRID==0) || (GRID==1) )
   x_lbl = 'none'   ! dummy
   x_min = 'none'   ! dummy
   x_max = 'none'   ! dummy
   x_stp = 'none'   ! dummy

   y_lbl = 'none'   ! dummy
   y_min = 'none'   ! dummy
   y_max = 'none'   ! dummy
   y_stp = 'none'   ! dummy

   lon_ctr  = 'none'   ! dummy
   lat_ctr  = 'none'   ! dummy
   lon_lol  = 'none'   ! dummy
   lat_lol  = 'none'   ! dummy
   lon_upr  = 'none'   ! dummy
   lat_upr  = 'none'   ! dummy
   lon_anot = 'none'   ! dummy
   lat_anot = 'none'   ! dummy
   lon_grid = 'none'   ! dummy
   lat_grid = 'none'   ! dummy
#elif (GRID==2)
   lambda_lbl = 'none'   ! dummy
   lambda_min = 'none'   ! dummy
   lambda_max = 'none'   ! dummy
   lambda_stp = 'none'   ! dummy

   phi_lbl = 'none'   ! dummy
   phi_min = 'none'   ! dummy
   phi_max = 'none'   ! dummy
   phi_stp = 'none'   ! dummy
#endif

end if

close(n_unit, status='keep')

!-------- Plotting of data --------

#if ( (GRID ==0) || (GRID == 1) )

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = &
#elif ( defined(NAG) )
call & 
#endif
   system(GMT_SCRIPT_SHELL//' '//GMT_SCRIPT_PATH &
         //'/plan_view.gmt' &
         //' '//trim(domain) &
         //' '//trim(runname)//trim(ergnum)//'_'//trim(ch_data) &
         //' '//trim(ch_data) &
         //' '//trim(ch_data_unit) &
         //' '//trim(adjustl(dx)) &
         //' '//trim(adjustl(x_min)) &
         //' '//trim(adjustl(x_max)) &
         //' '//trim(adjustl(x_stp)) &
         //' '//trim(adjustl(y_min)) &
         //' '//trim(adjustl(y_max)) &
         //' '//trim(adjustl(y_stp)) &
         //' '//trim(adjustl(x_lbl)) &
         //' '//trim(adjustl(y_lbl)) &
         //' '//trim(adjustl(lon_ctr)) &
         //' '//trim(adjustl(lat_ctr)) &
         //' '//trim(adjustl(lon_lol)) &
         //' '//trim(adjustl(lat_lol)) &
         //' '//trim(adjustl(lon_upr)) &
         //' '//trim(adjustl(lat_upr)) &
         //' '//trim(adjustl(lon_anot)) &
         //' '//trim(adjustl(lat_anot)) &
         //' '//trim(adjustl(lon_grid)) &
         //' '//trim(adjustl(lat_grid)) &
         //' '//trim(cb_flag) &
         //' '//trim(cl_flag))

#elif (GRID ==2)

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = &
#elif ( defined(NAG) )
call & 
#endif
   system(GMT_SCRIPT_SHELL//' '//GMT_SCRIPT_PATH &
         //'/plan_view_lonlat.gmt' &
         //' '//trim(domain) &
         //' '//trim(runname)//trim(ergnum)//'_'//trim(ch_data) &
         //' '//trim(ch_data) &
         //' '//trim(ch_data_unit) &
         //' '//trim(adjustl(dlambda)) &
         //' '//trim(adjustl(dphi)) &
         //' '//trim(adjustl(lambda_min)) &
         //' '//trim(adjustl(lambda_max)) &
         //' '//trim(adjustl(lambda_stp)) &
         //' '//trim(adjustl(phi_min)) &
         //' '//trim(adjustl(phi_max)) &
         //' '//trim(adjustl(phi_stp)) &
         //' '//trim(adjustl(lambda_lbl)) &
         //' '//trim(adjustl(phi_lbl)) &
         //' '//trim(cb_flag) &
         //' '//trim(cl_flag))

#endif

end subroutine plan_view

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  t i m e _ s e r i e s

!   Purpose    :  Plotting of time-series data (volume, area etc.).

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine time_series(domain, runname)

use sicograph_variables

#if defined(NAG)
use f90_unix_proc
    ! Required for executing shell commands with "call system('...')"
#endif

implicit none
integer :: n
integer :: ndata
integer :: iexit
integer :: ios
integer :: menue=0
integer, parameter :: n_unit=11
real, dimension(1000001) :: data
character (len=256) :: runname
character (len=256) :: para_file
character (len=256) :: time_min, time_max, time_stp, time_lbl, &
                       data_min, data_max, data_stp, data_lbl
character (len= 16) :: domain, ch_data
logical :: menue_flag=.false.

interface
  subroutine read_plot_par(n_unit, lbl, val1, val2, val3, val4, val5)
    implicit none
    integer n_unit
    character (len=256) :: lbl, val1
    character (len=256), optional :: val2, val3, val4, val5
    end subroutine read_plot_par
end interface

#if ( defined(INTEL) )
interface
  integer function system(commanda)
  character (len=*) commanda
  end function system
end interface
#endif

!-------- Reading of time-series data --------

call read_ser(runname, ndata)

!-------- Menue --------

do

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') '  (1) Temperature-deviation forcing'
   write(6,'(1x,a)') '  (2) Sea-level forcing'
   write(6,'(1x,a)') '  (3) Maximum ice thickness'
   write(6,'(1x,a)') '  (4) Maximum surface elevation'
   write(6,'(1x,a)') '  (5) Total ice volume'
   write(6,'(1x,a)') '  (6) Temperate ice volume'
   write(6,'(1x,a)') '  (7) Freshwater flux'
#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */
   write(6,'(1x,a)') '  (8) Sea-level equivalent'
#else   /* Martian ice sheet */
   write(6,'(1x,a)') '  (8) Maximum basal temperature (relative to pressure melting)'
#endif
   write(6,'(1x,a)') '  (9) Ice-covered area' 
   write(6,'(1x,a)') ' (10) Area covered by temperate ice'
   write(6,'(1x,a)') ' (11) Basal melting rate'
   write(6,'(1x,a)') ' (12) Temperate-layer drainage'
   write(6,'(1x,a)') ' (13) Maximum thickness of temperate ice'
   write(6,'(1x,a)') ' (14) Maximum surface velocity'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' > '
   read (5,*) menue

   if (menue == 1) then
      data    =  D_Ts
      ch_data = 'D_Ts'
      menue_flag = .true.
   else if (menue == 2) then
      data    =  z_sl
      ch_data = 'z_sl'
      menue_flag = .true.
   else if (menue == 3) then
      data    =  H_max
      ch_data = 'H_max'
      menue_flag = .true.
   else if (menue == 4) then
      data    =  zs_max
      ch_data = 'zs_max'
      menue_flag = .true.
   else if (menue == 5) then
      data    =  V_tot
      ch_data = 'V_tot'
      menue_flag = .true.
   else if (menue == 6) then
      data    =  V_temp
      ch_data = 'V_temp'
      menue_flag = .true.
   else if (menue == 7) then
      data    =  V_fw
      ch_data = 'V_fw'
      menue_flag = .true.
   else if (menue == 8) then
#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */
      data    =  z_sle
      ch_data = 'z_sle'
#else   /* Martian ice sheet */
      data    =  Tbh_max
      ch_data = 'Tbh_max'
#endif
      menue_flag = .true.
   else if (menue == 9) then
      data    =  A_ib
      ch_data = 'A_ib'
      menue_flag = .true.
   else if (menue == 10) then
      data    =  A_tb
      ch_data = 'A_tb'
      menue_flag = .true.
   else if (menue == 11) then
      data    =  V_bm
      ch_data = 'V_bm'
      menue_flag = .true.
   else if (menue == 12) then
      data    =  V_tld
      ch_data = 'V_tld'
      menue_flag = .true.
   else if (menue == 13) then
      data    =  H_t_max
      ch_data = 'H_t_max'
      menue_flag = .true.
   else if (menue == 14) then
      data    =  vs_max
      ch_data = 'vs_max'
      menue_flag = .true.
   end if

   if (menue_flag) exit

end do

!-------- Writing of data on temporary file --------

open(n_unit, iostat=ios, &
         file=GMT_SCRIPT_PATH//'/tmp/' &
         //trim(runname)//'_'//trim(ch_data)//'_tmp.ser', &
         status='replace')

do n=1, ndata
   write(n_unit,'(2(2x,1pe10.3))') time(n), data(n)
end do

close(n_unit, status='keep')

!-------- Reading of plot parameters --------

para_file = 'time_series_'//trim(domain)//'.dat'

open(n_unit, iostat=ios, &
     file='parameter_files/'//trim(para_file), status='old')

if (ios == 0) then

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' available.'
   write(6,'(1x,a)') 'Parameters listed in this file used.'

   call read_plot_par(n_unit, time_lbl, time_min, time_max, time_stp)
   do n=1, menue
      call read_plot_par(n_unit, data_lbl, data_min, data_max, data_stp)
   end do

else

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' not available.'
   write(6,'(1x,a)') 'Parameters will be computed automatically.'

   time_lbl = 'none'   ! dummy
   time_min = 'none'   ! dummy
   time_max = 'none'   ! dummy
   time_stp = 'none'   ! dummy

   data_lbl = 'none'   ! dummy
   data_min = 'none'   ! dummy
   data_max = 'none'   ! dummy
   data_stp = 'none'   ! dummy

end if

close(n_unit, status='keep')

!-------- Plotting of data --------

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = &
#elif ( defined(NAG) )
call & 
#endif
   system(GMT_SCRIPT_SHELL//' '//GMT_SCRIPT_PATH &
         //'/time_series.gmt' &
         //' '//trim(domain) &
         //' '//trim(runname)//'_'//trim(ch_data) &
         //' '//trim(ch_data) &
         //' '//trim(adjustl(time_min)) &
         //' '//trim(adjustl(time_max)) &
         //' '//trim(adjustl(time_stp)) &
         //' '//trim(adjustl(data_min)) &
         //' '//trim(adjustl(data_max)) &
         //' '//trim(adjustl(data_stp)) &
         //' '//trim(adjustl(time_lbl)) &
         //' '//trim(adjustl(data_lbl)))

end subroutine time_series

#if defined(HEINO)

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  t i m e _ s e r i e s _ s e d

!   Purpose    :  Plotting of time-series data for the sediment region of the
!                 HEINO set-up.

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine time_series_sed(domain, runname)

use sicograph_variables

#if defined(NAG)
use f90_unix_proc
    ! Required for executing shell commands with "call system('...')"
#endif

implicit none
integer :: n
integer :: ndata
integer :: iexit
integer :: ios
integer :: menue=0
integer, parameter :: n_unit=11
real, dimension(1000001) :: data
character (len=256) :: runname
character (len=256) :: para_file
character (len=256) :: time_min, time_max, time_stp, time_lbl, &
                       data_min, data_max, data_stp, data_lbl
character (len= 16) :: domain, ch_data
logical :: menue_flag=.false.

interface
  subroutine read_plot_par(n_unit, lbl, val1, val2, val3, val4, val5)
    implicit none
    integer n_unit
    character (len=256) :: lbl, val1
    character (len=256), optional :: val2, val3, val4, val5
    end subroutine read_plot_par
end interface

#if ( defined(INTEL) )
interface
  integer function system(commanda)
  character (len=*) commanda
  end function system
end interface
#endif

!-------- Reading of time-series data --------

call read_sed(runname, ndata)

!-------- Menue --------

do

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') '  (1) Temperature-deviation forcing'
   write(6,'(1x,a)') '  (2) Sea-level forcing'
   write(6,'(1x,a)') '  (3) Average ice thickness'
   write(6,'(1x,a)') '  (4) Average basal temperature (relative to pressure melting)'
   write(6,'(1x,a)') '  (5) Temperate basal area'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' > '
   read (5,*) menue

   if (menue == 1) then
      data    =  D_Ts
      ch_data = 'D_Ts'
      menue_flag = .true.
   else if (menue == 2) then
      data    =  z_sl
      ch_data = 'z_sl'
      menue_flag = .true.
   else if (menue == 3) then
      data    =  H_ave_sed
      ch_data = 'H_ave'
      menue_flag = .true.
   else if (menue == 4) then
      data    =  Tbh_ave_sed
      ch_data = 'Tbh_ave'
      menue_flag = .true.
   else if (menue == 5) then
      data    =  Atb_sed
      ch_data = 'Atb'
      menue_flag = .true.
   end if

   if (menue_flag) exit

end do

!-------- Writing of data on temporary file --------

open(n_unit, iostat=ios, &
         file=GMT_SCRIPT_PATH//'/tmp/' &
         //trim(runname)//'_'//trim(ch_data)//'_tmp.ser', &
         status='replace')

do n=1, ndata
   write(n_unit,'(2(2x,1pe10.3))') time(n), data(n)
end do

close(n_unit, status='keep')

!-------- Reading of plot parameters --------

para_file = 'time_series_sed_'//trim(domain)//'.dat'

open(n_unit, iostat=ios, &
     file='parameter_files/'//trim(para_file), status='old')

if (ios == 0) then

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' available.'
   write(6,'(1x,a)') 'Parameters listed in this file used.'

   call read_plot_par(n_unit, time_lbl, time_min, time_max, time_stp)
   do n=1, menue
      call read_plot_par(n_unit, data_lbl, data_min, data_max, data_stp)
   end do

else

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' not available.'
   write(6,'(1x,a)') 'Parameters will be computed automatically.'

   time_lbl = 'none'   ! dummy
   time_min = 'none'   ! dummy
   time_max = 'none'   ! dummy
   time_stp = 'none'   ! dummy

   data_lbl = 'none'   ! dummy
   data_min = 'none'   ! dummy
   data_max = 'none'   ! dummy
   data_stp = 'none'   ! dummy

end if

close(n_unit, status='keep')

!-------- Plotting of data --------

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = &
#elif ( defined(NAG) )
call & 
#endif
   system(GMT_SCRIPT_SHELL//' '//GMT_SCRIPT_PATH &
         //'/time_series.gmt' &
         //' '//trim(domain) &
         //' '//trim(runname)//'_'//trim(ch_data) &
         //' '//trim(ch_data) &
         //' '//trim(adjustl(time_min)) &
         //' '//trim(adjustl(time_max)) &
         //' '//trim(adjustl(time_stp)) &
         //' '//trim(adjustl(data_min)) &
         //' '//trim(adjustl(data_max)) &
         //' '//trim(adjustl(data_stp)) &
         //' '//trim(adjustl(time_lbl)) &
         //' '//trim(adjustl(data_lbl)))

end subroutine time_series_sed

#endif

#if ( defined(ANT) \
      || defined(EMTP2SGE) \
      || defined(GRL) \
      || defined(HEINO) \
      || defined(NMARS) )

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  t i m e _ s e r i e s _ c o r e

!   Purpose    :  Plotting of time-series data for ice cores or selected points.

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine time_series_core(domain, runname)

use sicograph_variables

#if defined(NAG)
use f90_unix_proc
    ! Required for executing shell commands with "call system('...')"
#endif

implicit none
integer :: n
integer :: ndata
integer :: iexit
integer :: ios
integer :: menue=0, n_core=0
integer, parameter :: n_unit=11
real, dimension(1000001) :: data
character (len=256) :: runname
character (len=256) :: para_file
character (len=256) :: time_min, time_max, time_stp, time_lbl, &
                       data_min, data_max, data_stp, data_lbl
character (len= 16) :: domain, ch_data
logical :: menue_flag=.false.

interface
  subroutine read_plot_par(n_unit, lbl, val1, val2, val3, val4, val5)
    implicit none
    integer n_unit
    character (len=256) :: lbl, val1
    character (len=256), optional :: val2, val3, val4, val5
    end subroutine read_plot_par
end interface

#if ( defined(INTEL) )
interface
  integer function system(commanda)
  character (len=*) commanda
  end function system
end interface
#endif

!-------- Reading of time-series data --------

call read_core(runname, ndata)

!-------- Menue --------

do

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') '  (1) Temperature-deviation forcing'
   write(6,'(1x,a)') '  (2) Sea-level forcing'
   write(6,'(1x,a)') '  (3) Ice thickness'
   write(6,'(1x,a)') '  (4) Surface velocity'
   write(6,'(1x,a)') '  (5) Basal temperature'
   write(6,'(1x,a)') '  (6) Basal frictional heating'
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' > '
   read (5,*) menue

   if (menue >= 3) then

#if defined(ANT)
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)') '  (1) Vostok'
      write(6,'(1x,a)') '  (2) Dome A'
      write(6,'(1x,a)') '  (3) Dome C'
      write(6,'(1x,a)') '  (4) Dome F'
      write(6,'(1x,a)') '  (5) Kohnen'
      write(6,'(1x,a)') '  (6) Byrd'
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)',advance='no') ' > '
      read (5,*) n_core
#elif defined(EMTP2SGE)
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)') '  (1) P1'
      write(6,'(1x,a)') '  (2) P2'
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)',advance='no') ' > '
      read (5,*) n_core
#elif defined(GRL)
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)') '  (1) GRIP'
      write(6,'(1x,a)') '  (2) GISP2'
      write(6,'(1x,a)') '  (3) Dye3'
      write(6,'(1x,a)') '  (4) Camp Century'
      write(6,'(1x,a)') '  (5) NGRIP'
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)',advance='no') ' > '
      read (5,*) n_core
#elif defined(HEINO)
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)') '  (1) P1'
      write(6,'(1x,a)') '  (2) P2'
      write(6,'(1x,a)') '  (3) P3'
      write(6,'(1x,a)') '  (4) P4'
      write(6,'(1x,a)') '  (5) P5'
      write(6,'(1x,a)') '  (6) P6'
      write(6,'(1x,a)') '  (7) P7'
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)',advance='no') ' > '
      read (5,*) n_core
#elif defined(NMARS)
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)') '  (1) NP'
      write(6,'(1x,a)') '  (2) C1'
      write(6,'(1x,a)') '  (3) C2'
      write(6,'(1x,a)') ' '
      write(6,'(1x,a)',advance='no') ' > '
      read (5,*) n_core
#endif

   end if

   if (menue == 1) then

      data    =  D_Ts
      ch_data = 'D_Ts'
      menue_flag = .true.

   else if (menue == 2) then

      data    =  z_sl
      ch_data = 'z_sl'
      menue_flag = .true.

   else if (menue == 3) then

#if defined(ANT)
      if (n_core == 1) then
         data    =  H_Vo
         ch_data = 'H_Vo'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  H_DA
         ch_data = 'H_DA'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  H_DC
         ch_data = 'H_DC'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  H_DF
         ch_data = 'H_DF'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  H_Ko
         ch_data = 'H_Ko'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  H_By
         ch_data = 'H_By'
         menue_flag = .true.
      end if
#elif defined(EMTP2SGE)
      if (n_core == 1) then
         data    =  H_P1
         ch_data = 'H_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  H_P2
         ch_data = 'H_P2'
         menue_flag = .true.
      end if
#elif defined(GRL)
      if (n_core == 1) then
         data    =  H_GR
         ch_data = 'H_GR'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  H_G2
         ch_data = 'H_G2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  H_D3
         ch_data = 'H_D3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  H_CC
         ch_data = 'H_CC'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  H_NG
         ch_data = 'H_NG'
         menue_flag = .true.
      end if
#elif defined(HEINO)
      if (n_core == 1) then
         data    =  H_P1
         ch_data = 'H_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  H_P2
         ch_data = 'H_P2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  H_P3
         ch_data = 'H_P3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  H_P4
         ch_data = 'H_P4'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  H_P5
         ch_data = 'H_P5'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  H_P6
         ch_data = 'H_P6'
         menue_flag = .true.
      else if (n_core == 7) then
         data    =  H_P7
         ch_data = 'H_P7'
         menue_flag = .true.
      end if
#elif defined(NMARS)
      if (n_core == 1) then
         data    =  H_NP
         ch_data = 'H_NP'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  H_C1
         ch_data = 'H_C1'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  H_C2
         ch_data = 'H_C2'
         menue_flag = .true.
      end if
#endif

   else if (menue == 4) then

#if defined(ANT)
      if (n_core == 1) then
         data    =  vs_Vo
         ch_data = 'vs_Vo'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  vs_DA
         ch_data = 'vs_DA'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  vs_DC
         ch_data = 'vs_DC'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  vs_DF
         ch_data = 'vs_DF'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  vs_Ko
         ch_data = 'vs_Ko'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  vs_By
         ch_data = 'vs_By'
         menue_flag = .true.
      end if
#elif defined(EMTP2SGE)
      if (n_core == 1) then
         data    =  vs_P1
         ch_data = 'vs_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  vs_P2
         ch_data = 'vs_P2'
         menue_flag = .true.
      end if
#elif defined(GRL)
      if (n_core == 1) then
         data    =  vs_GR
         ch_data = 'vs_GR'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  vs_G2
         ch_data = 'vs_G2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  vs_D3
         ch_data = 'vs_D3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  vs_CC
         ch_data = 'vs_CC'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  vs_NG
         ch_data = 'vs_NG'
         menue_flag = .true.
      end if
#elif defined(HEINO)
      if (n_core == 1) then
         data    =  vs_P1
         ch_data = 'vs_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  vs_P2
         ch_data = 'vs_P2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  vs_P3
         ch_data = 'vs_P3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  vs_P4
         ch_data = 'vs_P4'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  vs_P5
         ch_data = 'vs_P5'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  vs_P6
         ch_data = 'vs_P6'
         menue_flag = .true.
      else if (n_core == 7) then
         data    =  vs_P7
         ch_data = 'vs_P7'
         menue_flag = .true.
      end if
#elif defined(NMARS)
      if (n_core == 1) then
         data    =  vs_NP
         ch_data = 'vs_NP'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  vs_C1
         ch_data = 'vs_C1'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  vs_C2
         ch_data = 'vs_C2'
         menue_flag = .true.
      end if
#endif

   else if (menue == 5) then

#if defined(ANT)
      if (n_core == 1) then
         data    =  Tb_Vo
         ch_data = 'Tb_Vo'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Tb_DA
         ch_data = 'Tb_DA'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Tb_DC
         ch_data = 'Tb_DC'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  Tb_DF
         ch_data = 'Tb_DF'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  Tb_Ko
         ch_data = 'Tb_Ko'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  Tb_By
         ch_data = 'Tb_By'
         menue_flag = .true.
      end if
#elif defined(EMTP2SGE)
      if (n_core == 1) then
         data    =  Tb_P1
         ch_data = 'Tb_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Tb_P2
         ch_data = 'Tb_P2'
         menue_flag = .true.
      end if
#elif defined(GRL)
      if (n_core == 1) then
         data    =  Tb_GR
         ch_data = 'Tb_GR'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Tb_G2
         ch_data = 'Tb_G2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Tb_D3
         ch_data = 'Tb_D3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  Tb_CC
         ch_data = 'Tb_CC'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  Tb_NG
         ch_data = 'Tb_NG'
         menue_flag = .true.
      end if
#elif defined(HEINO)
      if (n_core == 1) then
         data    =  Tb_P1
         ch_data = 'Tb_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Tb_P2
         ch_data = 'Tb_P2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Tb_P3
         ch_data = 'Tb_P3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  Tb_P4
         ch_data = 'Tb_P4'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  Tb_P5
         ch_data = 'Tb_P5'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  Tb_P6
         ch_data = 'Tb_P6'
         menue_flag = .true.
      else if (n_core == 7) then
         data    =  Tb_P7
         ch_data = 'Tb_P7'
         menue_flag = .true.
      end if
#elif defined(NMARS)
      if (n_core == 1) then
         data    =  Tb_NP
         ch_data = 'Tb_NP'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Tb_C1
         ch_data = 'Tb_C1'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Tb_C2
         ch_data = 'Tb_C2'
         menue_flag = .true.
      end if
#endif

   else if (menue == 6) then

#if defined(ANT)
      if (n_core == 1) then
         data    =  Rb_Vo
         ch_data = 'Rb_Vo'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Rb_DA
         ch_data = 'Rb_DA'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Rb_DC
         ch_data = 'Rb_DC'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  Rb_DF
         ch_data = 'Rb_DF'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  Rb_Ko
         ch_data = 'Rb_Ko'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  Rb_By
         ch_data = 'Rb_By'
         menue_flag = .true.
      end if
#elif defined(EMTP2SGE)
      if (n_core == 1) then
         data    =  Rb_P1
         ch_data = 'Rb_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Rb_P2
         ch_data = 'Rb_P2'
         menue_flag = .true.
      end if
#elif defined(GRL)
      if (n_core == 1) then
         data    =  Rb_GR
         ch_data = 'Rb_GR'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Rb_G2
         ch_data = 'Rb_G2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Rb_D3
         ch_data = 'Rb_D3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  Rb_CC
         ch_data = 'Rb_CC'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  Rb_NG
         ch_data = 'Rb_NG'
         menue_flag = .true.
      end if
#elif defined(HEINO)
      if (n_core == 1) then
         data    =  Rb_P1
         ch_data = 'Rb_P1'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Rb_P2
         ch_data = 'Rb_P2'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Rb_P3
         ch_data = 'Rb_P3'
         menue_flag = .true.
      else if (n_core == 4) then
         data    =  Rb_P4
         ch_data = 'Rb_P4'
         menue_flag = .true.
      else if (n_core == 5) then
         data    =  Rb_P5
         ch_data = 'Rb_P5'
         menue_flag = .true.
      else if (n_core == 6) then
         data    =  Rb_P6
         ch_data = 'Rb_P6'
         menue_flag = .true.
      else if (n_core == 7) then
         data    =  Rb_P7
         ch_data = 'Rb_P7'
         menue_flag = .true.
      end if
#elif defined(NMARS)
      if (n_core == 1) then
         data    =  Rb_NP
         ch_data = 'Rb_NP'
         menue_flag = .true.
      else if (n_core == 2) then
         data    =  Rb_C1
         ch_data = 'Rb_C1'
         menue_flag = .true.
      else if (n_core == 3) then
         data    =  Rb_C2
         ch_data = 'Rb_C2'
         menue_flag = .true.
      end if
#endif

   end if

   if (menue_flag) exit

end do

!-------- Writing of data on temporary file --------

open(n_unit, iostat=ios, &
         file=GMT_SCRIPT_PATH//'/tmp/' &
         //trim(runname)//'_'//trim(ch_data)//'_tmp.ser', &
         status='replace')

do n=1, ndata
   write(n_unit,'(2(2x,1pe10.3))') time(n), data(n)
end do

close(n_unit, status='keep')

!-------- Reading of plot parameters --------

para_file = 'time_series_core_'//trim(domain)//'.dat'

open(n_unit, iostat=ios, &
     file='parameter_files/'//trim(para_file), status='old')

if (ios == 0) then

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' available.'
   write(6,'(1x,a)') 'Parameters listed in this file used.'

   call read_plot_par(n_unit, time_lbl, time_min, time_max, time_stp)
   do n=1, menue
      call read_plot_par(n_unit, data_lbl, data_min, data_max, data_stp)
   end do

else

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' not available.'
   write(6,'(1x,a)') 'Parameters will be computed automatically.'

   time_lbl = 'none'   ! dummy
   time_min = 'none'   ! dummy
   time_max = 'none'   ! dummy
   time_stp = 'none'   ! dummy

   data_lbl = 'none'   ! dummy
   data_min = 'none'   ! dummy
   data_max = 'none'   ! dummy
   data_stp = 'none'   ! dummy

end if

close(n_unit, status='keep')

!-------- Plotting of data --------

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = &
#elif ( defined(NAG) )
call & 
#endif
   system(GMT_SCRIPT_SHELL//' '//GMT_SCRIPT_PATH &
         //'/time_series.gmt' &
         //' '//trim(domain) &
         //' '//trim(runname)//'_'//trim(ch_data) &
         //' '//trim(ch_data) &
         //' '//trim(adjustl(time_min)) &
         //' '//trim(adjustl(time_max)) &
         //' '//trim(adjustl(time_stp)) &
         //' '//trim(adjustl(data_min)) &
         //' '//trim(adjustl(data_max)) &
         //' '//trim(adjustl(data_stp)) &
         //' '//trim(adjustl(time_lbl)) &
         //' '//trim(adjustl(data_lbl)))

end subroutine time_series_core

#endif

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  s c a t t e r _ p l o t

!   Purpose    :  Scatter plots (simulation results vs. data) for a given
!                 time slice.

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine scatter_plot(domain, runname, topo_marker)

use sicograph_variables

#if defined(NAG)
use f90_unix_proc
    ! Required for executing shell commands with "call system('...')"
#endif

implicit none

character (len=256), intent(in) :: runname
character (len= 16), intent(in) :: domain, topo_marker

integer :: i, j, m, n
integer :: menue, menue_read_data
integer :: iexit
integer :: ios
integer :: i_cb_flag, i_cl_flag
integer :: ndata, ndata_mean
integer, parameter :: n_unit=11
integer, dimension(0:IMAX,0:JMAX) :: maske_gr_sim, maske_gr_sedi
real, dimension(0:IMAX,0:JMAX) :: zs_gr_sim, zb_gr_sim, zb0_gr_sim, &
                                  H_c_gr_sim, H_t_gr_sim, v_s_gr_sim
real, dimension((IMAX+1)*(JMAX+1)) :: data_obs, data_sim
real :: data_diff_mean, data_diff_rms
real, parameter :: eps=1.0e-05
character (len=256) :: para_file
character (len=256) :: data_obs_lbl, data_obs_min, data_obs_max, data_obs_stp, &
                       data_sim_lbl, data_sim_min, data_sim_max, data_sim_stp
character (len= 16) :: ch_data, dx, dx_int, cb_flag, cl_flag, dlambda, &
	  	       dlambda_int, dphi, dphi_int
character (len=  2) :: ergnum
character           :: ch_dummy
logical :: menue_flag=.false.

interface
  subroutine read_plot_par(n_unit, lbl, val1, val2, val3, val4, val5)
    implicit none
    integer n_unit
    character (len=256) :: lbl, val1
    character (len=256), optional :: val2, val3, val4, val5
    end subroutine read_plot_par
end interface

#if ( defined(INTEL) )
interface
  integer function system(commanda)
  character (len=*) commanda
  end function system
end interface
#endif

!-------- Grid spacing --------

#if ( (GRID ==0) || (GRID == 1) )

if (abs(DX-5.0).lt.eps) then
   dx =   '5.0'; dx_int =  '05'
else if (abs(DX-10.0).lt.eps) then
   dx =  '10.0'; dx_int =  '10'
else if (abs(DX-20.0).lt.eps) then
   dx =  '20.0'; dx_int =  '20'
else if (abs(DX-25.0).lt.eps) then
   dx =  '25.0'; dx_int =  '25'
else if (abs(DX-40.0).lt.eps) then
   dx =  '40.0'; dx_int =  '40'
else if (abs(DX-50.0).lt.eps) then
   dx =  '50.0'; dx_int =  '50'
else if (abs(DX-75.0).lt.eps) then
   dx =  '75.0'; dx_int =  '75'
else if (abs(DX-80.0).lt.eps) then
   dx =  '80.0'; dx_int =  '80'
else if (abs(DX-100.0).lt.eps) then
   dx = '100.0'; dx_int = '100'
else if (abs(DX-150.0).lt.eps) then
   dx = '150.0'; dx_int = '150'
else if (abs(DX-160.0).lt.eps) then
   dx = '160.0'; dx_int = '160'
else if (abs(DX-200.0).lt.eps) then
   dx = '200.0'; dx_int = '200'
else
   stop ' Grid spacing cannot be determined!'
end if

#elif (GRID==2)

if ( (abs(DLAMBDA-(1.0d0/3.0d0).lt.eps)) &
     .and. (abs(DPHI-(1.0d0/3.0d0).lt.eps)) ) then
   dlambda = '20.0'; dphi = '20.0';  dlambda_int = '20'; dphi_int = '20'
else if ( (abs(DLAMBDA-(1.0d0/6.0d0).lt.eps)) &
          .and. (abs(DPHI-(1.0d0/6.0d0).lt.eps)) ) then
   dlambda = '10.0'; dphi = '10.0';  dlambda_int = '10'; dphi_int = '10'
else if ( (abs(DLAMBDA-(1.0d0/12.0d0).lt.eps)) &
          .and. (abs(DPHI-(1.0d0/12.0d0).lt.eps)) ) then
   dlambda = '5.0'; dphi = '5.0';  dlambda_int = '05'; dphi_int = '05'
else
   stop ' Grid spacing cannot be determined!'
end if

#endif

!-------- Menue --------

do

   write(6,'(1x,a)') ' '
#if defined(GRL)
   write(6,'(1x,a)') 'Only for the NEGIS area:'
#endif
   write(6,'(1x,a)') '  (2) Ice thickness'
#if defined(GRL)
   write(6,'(1x,a)') '  (5) Surface velocity'
#endif

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' > '
   read (5,*) menue

   if (menue == 2) then
      menue_read_data = 12
      menue_flag = .true.
   else if (menue == 5) then
      menue_read_data = 20
      menue_flag      = .true.
   end if

   if (menue_flag) exit

end do

!-------- Reading of simulated and observed data --------

call read_erg(runname, ergnum, menue)

zs_gr_sim    = zs_gr
zb_gr_sim    = zb_gr
zb0_gr_sim   = zb0_gr
maske_gr_sim = maske_gr
H_c_gr_sim   = H_c_gr
H_t_gr_sim   = H_t_gr

do i=0, IMAX
do j=0, JMAX
   if (maske_gr_sim(i,j) == 0) then
      v_s_gr_sim(i,j) = sqrt( &
            0.25*(vx_c_gr(i,j,KCMAX)+vx_c_gr(i-1,j,KCMAX))**2 &
           +0.25*(vy_c_gr(i,j,KCMAX)+vy_c_gr(i,j-1,KCMAX))**2 )
   else
      v_s_gr_sim(i,j) = 0.0
   end if
end do
end do

#if ( (GRID==0) || (GRID==1) )
   call read_data(domain, topo_marker, dx_int, menue_read_data)
#elif (GRID==2)
   call read_data(domain, topo_marker, dphi_int, menue_read_data)
#endif

#if defined(GRL)

open(24, iostat=ios, &
     file=INPATH//'/grl/'//MASK_SEDI_FILE, &
     recl=8192, status='old')

if (ios /= 0) stop ' Error when opening the NEGIS mask file!'

do m=1, 6; read(24,'(a)') ch_dummy; end do

do j=JMAX, 0, -1
   read(24,2300) (maske_gr_sedi(i,j), i=0,IMAX)
end do

close(24, status='keep')

2300 format(IMAX(i1),i1)

#endif

!-------- Creation of data vectors --------

n              = 0
ndata          = 0
ndata_mean     = 0
data_diff_mean = 0.0
data_diff_rms  = 0.0

do i=0, IMAX
do j=0, JMAX

   if (maske_gr(i,j) < 2) then

#if defined(GRL)
      if (maske_gr_sedi(i,j) == 7) then   ! only NEGIS area
#endif

         n = n+1

         if (menue == 2) then

            data_obs(n)   = H_c_gr(i,j) + H_t_gr(i,j)
            data_sim(n)   = H_c_gr_sim(i,j) + H_t_gr_sim(i,j)
            ch_data       = 'H'

            if ((data_obs(n) > eps).and.(data_sim(n) > eps)) then
               ndata_mean     = ndata_mean+1
               data_diff_mean = data_diff_mean + (data_sim(n)-data_obs(n))
               data_diff_rms  = data_diff_rms  + (data_sim(n)-data_obs(n))**2
            end if

         else if (menue == 5) then

            data_obs(n)   = v_s_gr(i,j)
            data_sim(n)   = v_s_gr_sim(i,j)
            ch_data       = 'vs'

            if ((data_obs(n) > eps).and.(data_sim(n) > eps)) then
               ndata_mean     = ndata_mean+1
               data_diff_mean = data_diff_mean + (data_sim(n)-data_obs(n))
               data_diff_rms  = data_diff_rms  + (data_sim(n)-data_obs(n))**2
            end if

         end if

#if defined(GRL)
      end if
#endif

   end if

end do
end do

ndata = n

data_diff_mean =      data_diff_mean/real(ndata_mean)
data_diff_rms  = sqrt(data_diff_rms /real(ndata_mean))

write(6,'(1x,a)') ' '
write(6,'(1x,a,es11.3,a)') 'Mean of misfit:', data_diff_mean, ' [data units]'
write(6,'(1x,a,es11.3,a)') 'RMS of misfit :', data_diff_rms , ' [data units]'

!-------- Reading of plot parameters --------

para_file = 'scatter_plot_'//trim(domain)//'.dat'

open(n_unit, iostat=ios, &
     file='parameter_files/'//trim(para_file), status='old')

if (ios == 0) then

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' available.'
   write(6,'(1x,a)') 'Parameters listed in this file used.'

   do n=1, menue
      call read_plot_par(n_unit, data_obs_lbl, data_obs_min, data_obs_max, data_obs_stp)
      call read_plot_par(n_unit, data_sim_lbl, data_sim_min, data_sim_max, data_sim_stp)
   end do

else

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)') 'Plot-parameter file '//trim(para_file)//' not available.'
   write(6,'(1x,a)') 'Parameters will be computed automatically.'

   data_obs_lbl = 'none'   ! dummy
   data_obs_min = 'none'   ! dummy
   data_obs_max = 'none'   ! dummy
   data_obs_stp = 'none'   ! dummy
   data_sim_lbl = 'none'   ! dummy
   data_sim_min = 'none'   ! dummy
   data_sim_max = 'none'   ! dummy
   data_sim_stp = 'none'   ! dummy

end if

close(n_unit, status='keep')

!-------- Writing of data on temporary file --------

open(n_unit, iostat=ios, &
         file=GMT_SCRIPT_PATH//'/tmp/' &
         //trim(runname)//trim(ergnum)//'_'//trim(ch_data)//'_scatter' &
                                                          //'_tmp.sca', &
         status='replace')

do n=1, ndata
   write(n_unit,'(2(2x,1pe10.3))') data_obs(n), data_sim(n)
end do

close(n_unit, status='keep')

!-------- Plotting of data --------

#if ( defined(INTEL) || defined(GFORTRAN) || defined(G95) )
iexit = &
#elif ( defined(NAG) )
call & 
#endif
   system(GMT_SCRIPT_SHELL//' '//GMT_SCRIPT_PATH &
         //'/scatter.gmt' &
         //' '//trim(domain) &
         //' '//trim(runname)//trim(ergnum)//'_'//trim(ch_data)//'_scatter' &
         //' '//trim(ch_data) &
         //' '//trim(adjustl(data_obs_min)) &
         //' '//trim(adjustl(data_obs_max)) &
         //' '//trim(adjustl(data_obs_stp)) &
         //' '//trim(adjustl(data_sim_min)) &
         //' '//trim(adjustl(data_sim_max)) &
         //' '//trim(adjustl(data_sim_stp)) &
         //' '//trim(adjustl(data_obs_lbl)) &
         //' '//trim(adjustl(data_sim_lbl)) )

end subroutine scatter_plot

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  r e a d _ p l o t _ p a r

!   Purpose    :  Reading of plot parameters.

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine read_plot_par(n_unit, lbl, val1, val2, val3, val4, val5)

implicit none
integer n_unit
character check
character (len=256) :: lbl, val1
character (len=256), optional :: val2, val3, val4, val5
character (len=*), parameter :: form1='(a)', form2='(/)', &
          form3='(a24,1x,a15)', form4='(1x,a15)'

do
   read(n_unit,form1,advance='no') check
   if (check == '%') then   ! Comment line
      read(n_unit,form2,advance='no')
   else   ! Data line
      read(n_unit,form3,advance='no') lbl, val1
      if (present(val2)) read(n_unit,form4,advance='no') val2
      if (present(val3)) read(n_unit,form4,advance='no') val3
      if (present(val4)) read(n_unit,form4,advance='no') val4
      if (present(val5)) read(n_unit,form4,advance='no') val5
      read(n_unit,form2,advance='no')
      exit
   end if
end do

end subroutine read_plot_par

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  r e a d _ e r g 

!   Purpose    :  Reading and processing of data of time-slice files *.erg

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine read_erg(runname, ergnum, menue)

use sicograph_variables

implicit none
integer i, j, kc, kt, kr, n
integer ios
integer :: menue
integer maske_erg(0:JMAX,0:IMAX), n_cts_erg(0:JMAX,0:IMAX)
real BETA
real time_erg, delta_ts_erg, z_sl_erg, &
     xi_erg(0:IMAX), eta_erg(0:JMAX), &
     zs_erg(0:JMAX,0:IMAX), zm_erg(0:JMAX,0:IMAX), &
     zb_erg(0:JMAX,0:IMAX), H_c_erg(0:JMAX,0:IMAX), &
     H_t_erg(0:JMAX,0:IMAX), H_R_erg, &
     vx_c_erg(0:KCMAX,0:JMAX,0:IMAX), &
     vy_c_erg(0:KCMAX,0:JMAX,0:IMAX), &
     vz_c_erg(0:KCMAX,0:JMAX,0:IMAX), &
     vx_t_erg(0:KTMAX,0:JMAX,0:IMAX), &
     vy_t_erg(0:KTMAX,0:JMAX,0:IMAX), &
     vz_t_erg(0:KTMAX,0:JMAX,0:IMAX), &
     temp_c_erg(0:KCMAX,0:JMAX,0:IMAX), &
     age_c_erg(0:KCMAX,0:JMAX,0:IMAX), &
     omega_t_erg(0:KTMAX,0:JMAX,0:IMAX), &
     age_t_erg(0:KTMAX,0:JMAX,0:IMAX), &
     temp_r_erg(0:KRMAX,0:JMAX,0:IMAX), &
     qx_erg(0:JMAX,0:IMAX), qy_erg(0:JMAX,0:IMAX), &
     Q_bm_erg(0:JMAX,0:IMAX), Q_tld_erg(0:JMAX,0:IMAX),  &
     am_perp_erg(0:JMAX,0:IMAX)
character (len=256) :: runname
character (len=  2) :: ergnum

real, parameter :: &
       pi = 3.141592653589793, pi_inv = 1.0/pi, &
       pi_180 = pi/180.0, pi_180_inv = 180.0/pi

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

BETA = 8.70e-04   ! terrestrial Clausius-Clapeyron gradient, in K/m

#elif ( defined(NMARS) \
        || defined(SMARS) )   /* Martian ice sheet */

BETA = 3.30e-04   ! Martian Clausius-Clapeyron gradient, in K/m

#else

stop ' Subroutine read_erg: No valid domain specified!'

#endif

!-------- Enter name of time-slice file --------

write(6,'(1x,a)') ' '
write(6,'(1x,a,a)') 'Name of run: ', trim(runname)
write(6,'(1x,a)',advance='no') &
'Number of time-slice file (with leading zeros) > '
read (5,'(a)') ergnum

!-------- Reading of data from time-slice file --------

open(10, iostat=ios, &
         file=OUTPATH//'/'//trim(runname)//ergnum//'.erg', &
         status='old', form='unformatted')
if (ios /= 0) stop ' Error when opening the file *.erg!'

read(10) time_erg
read(10) delta_ts_erg
read(10) z_sl_erg
read(10) xi_erg
read(10) eta_erg
read(10) maske_erg
read(10) n_cts_erg
read(10) zs_erg
read(10) zm_erg
read(10) zb_erg
read(10) H_c_erg
read(10) H_t_erg
read(10) H_R_erg
read(10) vx_c_erg
read(10) vy_c_erg
read(10) vz_c_erg
read(10) vx_t_erg
read(10) vy_t_erg
read(10) vz_t_erg
read(10) temp_c_erg
read(10) omega_t_erg
read(10) temp_r_erg
read(10) Q_bm_erg
read(10) Q_tld_erg
read(10) am_perp_erg
read(10) qx_erg
read(10) qy_erg
read(10) age_c_erg
read(10) age_t_erg

close(10, status='keep')

!-------- General abbreviations --------

ea = exp(DEFORM) 

do kc=0, KCMAX
   zeta_c(kc) = real(kc)/real(KCMAX)
   eaz_c(kc)  = exp(DEFORM*zeta_c(kc)) 
   eaz_c_quotient(kc) = (eaz_c(kc)-1.0)/(ea-1.0)
end do

do kt=0, KTMAX
   zeta_t(kt) = real(kt)/real(KTMAX)
end do

!-------- Conversion of read data --------

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

time_gr = time_erg/(1.0e+03*YEAR_SEC)   ! s --> ka

#else   /* Martian ice sheet */

time_gr = time_erg/(1.0e+06*YEAR_SEC)   ! s --> Ma

#endif

delta_ts_gr = delta_ts_erg    ! deg C   
z_sl_gr     = z_sl_erg*0.001  ! m --> km
H_R_gr      = H_R_erg*0.001   ! m --> km

do i=0, IMAX
do j=0, JMAX

   maske_gr(i,j) = maske_erg(j,i)
   n_cts_gr(i,j) = n_cts_erg(j,i)

#if ( (GRID==0) || (GRID==1) )
   xi_gr(i)     = xi_erg(i)*0.001   ! m --> km
   eta_gr(j)    = eta_erg(j)*0.001  ! m --> km
#elif (GRID==2)
   xi_gr(i)     = xi_erg(i)*pi_180_inv   ! rad --> deg
   eta_gr(j)    = eta_erg(j)*pi_180_inv  ! rad --> deg
#endif

   zs_gr(i,j)  = zs_erg(j,i)*0.001   ! m --> km
   zm_gr(i,j)  = zm_erg(j,i)*0.001   ! m --> km
   zb_gr(i,j)  = zb_erg(j,i)*0.001   ! m --> km
   H_c_gr(i,j) = H_c_erg(j,i)*0.001  ! m --> km
   H_t_gr(i,j) = H_t_erg(j,i)*0.001  ! m --> km

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

   qx_gr(i,j) = qx_erg(j,i)*YEAR_SEC*0.001  ! m2/s --> km*m/a
   qy_gr(i,j) = qy_erg(j,i)*YEAR_SEC*0.001  ! m2/s --> km*m/a

   Q_bm_gr(i,j)    = Q_bm_erg(j,i)*YEAR_SEC     ! (m/s) --> (m/a)
   Q_tld_gr(i,j)   = Q_tld_erg(j,i)*YEAR_SEC    ! (m/s) --> (m/a)
   am_perp_gr(i,j) = am_perp_erg(j,i)*YEAR_SEC  ! (m/s) --> (m/a)

#else   /* Martian ice sheet */

   qx_gr(i,j) = qx_erg(j,i)*YEAR_SEC  ! m2/s --> m2/a
   qy_gr(i,j) = qy_erg(j,i)*YEAR_SEC  ! m2/s --> m2/a

   Q_bm_gr(i,j)    = Q_bm_erg(j,i)*YEAR_SEC*1000.0    ! (m/s) --> (mm/a)
   Q_tld_gr(i,j)   = Q_tld_erg(j,i)*YEAR_SEC*1000.0   ! (m/s) --> (mm/a)
   am_perp_gr(i,j) = am_perp_erg(j,i)*YEAR_SEC*1000.0 ! (m/s) --> (mm/a)

#endif

   do kc=0, KCMAX

      z_c_gr(i,j,kc) = zm_gr(i,j) &
            +H_c_gr(i,j)*eaz_c_quotient(kc)   ! in km

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

      vx_c_gr(i,j,kc) = vx_c_erg(kc,j,i)*YEAR_SEC 
!                                             ! (m/s) --> (m/a)
      vy_c_gr(i,j,kc) = vy_c_erg(kc,j,i)*YEAR_SEC
!                                             ! (m/s) --> (m/a)
      vz_c_gr(i,j,kc) = vz_c_erg(kc,j,i)*YEAR_SEC
!                                             ! (m/s) --> (m/a)
      age_c_gr(i,j,kc) = age_c_erg(kc,j,i)/(1.0e+03*YEAR_SEC)
!                                             ! s --> ka
#else   /* Martian ice sheet */

      vx_c_gr(i,j,kc) = vx_c_erg(kc,j,i)*YEAR_SEC*1000.0
!                                             ! (m/s) --> (mm/a)
      vy_c_gr(i,j,kc) = vy_c_erg(kc,j,i)*YEAR_SEC*1000.0
!                                             ! (m/s) --> (mm/a)
      vz_c_gr(i,j,kc) = vz_c_erg(kc,j,i)*YEAR_SEC*1000.0
!                                             ! (m/s) --> (mm/a)
      age_c_gr(i,j,kc) = age_c_erg(kc,j,i)/(1.0e+06*YEAR_SEC)
!                                             ! s --> Ma
#endif

      temp_c_gr(i,j,kc) = temp_c_erg(kc,j,i)

   end do

   do kt=0, KTMAX

      z_t_gr(i,j,kt) = zb_gr(i,j) &
                 +H_t_gr(i,j)*zeta_t(kt)  ! in km

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */

      vx_t_gr(i,j,kt) = vx_t_erg(kt,j,i)*YEAR_SEC
!                                             ! (m/s) --> (m/a)
      vy_t_gr(i,j,kt) = vy_t_erg(kt,j,i)*YEAR_SEC
!                                             ! (m/s) --> (m/a)
      vz_t_gr(i,j,kt) = vz_t_erg(kt,j,i)*YEAR_SEC
!                                             ! (m/s) --> (m/a)
      age_t_gr(i,j,kt) = age_t_erg(kt,j,i)/(1.0e+03*YEAR_SEC)
!                                             ! s --> ka

#else   /* Martian ice sheet */

      vx_t_gr(i,j,kt) = vx_t_erg(kt,j,i)*YEAR_SEC*1000.0
!                                             ! (m/s) --> (mm/a)
      vy_t_gr(i,j,kt) = vy_t_erg(kt,j,i)*YEAR_SEC*1000.0
!                                             ! (m/s) --> (mm/a)
      vz_t_gr(i,j,kt) = vz_t_erg(kt,j,i)*YEAR_SEC*1000.0
!                                             ! (m/s) --> (mm/a)
      age_t_gr(i,j,kt) = age_t_erg(kt,j,i)/(1.0e+06*YEAR_SEC)
!                                             ! s --> Ma

#endif

      omega_t_gr(i,j,kt) = omega_t_erg(kt,j,i)

   end do

   do kr=0, KRMAX

      z_r_gr(i,j,kr) = zb_gr(i,j) &
                 +H_R_gr*(real(kr)/real(KRMAX)-1.0)  ! in km

      temp_r_gr(i,j,kr) = temp_r_erg(kr,j,i)

   end do

end do
end do

!-------- Computation of temperature relative to pressure melting --------

do i=0, IMAX
do j=0, JMAX
do kc=0, KCMAX

   temph_c_gr(i,j,kc) = temp_c_gr(i,j,kc) &
      - ( -1000.0*BETA*H_c_gr(i,j)*(1.0-eaz_c_quotient(kc)) )

!    ! Factor 1000.0 required because H_c_gr(i,j) is in km instead of m

end do
end do
end do

!------------------------------------------------
! THIS IS JUST A HACK, SHOULD BE BLANKED OUT !!!
! 
! do i= 68,  70
! do j=108, 110
! 
!    write((i-68)*3+(j-108)+42,'(a,2f8.1)') ' (x,y) [km] =', xi_gr(i), eta_gr(j)
!    write((i-68)*3+(j-108)+42,'(a)') ' '
!    write((i-68)*3+(j-108)+42,'(a)') '    z [m]     T [C] '
!    write((i-68)*3+(j-108)+42,'(a)') ' -------------------'
! 
!    if (n_cts_gr(i,j) == -1) then
!       do kt=0, KTMAX-1
!          write((i-68)*3+(j-108)+42,'(2f10.3)') &
!             z_t_gr(i,j,kt)*1000.0, &
!             temp_c_gr(i,j,0)
!       end do
!    else
!       do kt=0, KTMAX-1
!          write((i-68)*3+(j-108)+42,'(2f10.3)') &
!             z_t_gr(i,j,kt)*1000.0, &
!             -1000.0*BETA*(H_c_gr(i,j)+H_t_gr(i,j)*(1.0-zeta_t(kt)))
!       end do
!    end if
! 
!    do kc=0, KCMAX
!       write((i-68)*3+(j-108)+42,'(2f10.3)') &
!          z_c_gr(i,j,kc)*1000.0, &
!          temp_c_gr(i,j,kc)
!    end do
! 
! end do
! end do
! 
! stop ' Profile data written in files fort.xxx!'
! 
! END OF HACK !!!
!------------------------------------------------

!-----------------------------------------------------
! THIS IS ANOTHER HACK, SHOULD ALSO BE BLANKED OUT !!!
!
! do i=0, IMAX
! do j=0, JMAX
!    write(41,'(2f8.1,f10.3)') xi_gr(i), eta_gr(j), &
!                              zs_gr(i,j)*1.0e+03   ! km --> m
! end do
! end do
!
! stop ' Surface topography data written in file fort.41!'
!
! END OF HACK !!!
!-----------------------------------------------------

end subroutine read_erg

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  r e a d _ s e r

!   Purpose    :  Reading of data of time-series files *.ser

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine read_ser(runname, ndata)

use sicograph_variables

implicit none
integer n, ndata
character (len=256) :: runname
character ch_dummy

!-------- Name of time-series file --------

write(6,'(1x,a)') ' '
write(6,'(1x,a,a)') 'Name of time-series file: ', trim(runname)//'.ser'

!-------- Reading of data from time-series file --------

open(10, &
     file=OUTPATH//'/'//trim(runname)//'.ser', &
     status='old')

read(10,'(a)') ch_dummy
read(10,'(a)') ch_dummy
read(10,'(a)') ch_dummy
read(10,'(a)') ch_dummy

do n=1, 1000001

   read(10,*,end=20) time(n), D_Ts(n), z_sl(n)
   read(10,*,end=20) H_max(n), zs_max(n), V_tot(n), V_temp(n), V_fw(n), &
#if ( defined(ANT) \
      || defined(GRL) \
      || defined(SCAND) \
      || defined(NHEM) \
      || defined(TIBET) \
      || defined(EMTP2SGE) \
      || defined(HEINO) )   /* terrestrial ice sheet */
                     z_sle(n)
#else   /* Martian ice sheet */
                     Tbh_max(n)
#endif
   read(10,*,end=20) A_ib(n), A_tb(n), V_bm(n), V_tld(n), &
                     H_t_max(n), vs_max(n)
   read(10,'(a)',end=20) ch_dummy

#if ( defined(NMARS) \
        || defined(SMARS) )   /* Martian ice sheet */
   time(n)   = time(n)   * 1.0e-03   ! ka -> Ma
   vs_max(n) = vs_max(n) * 1.0e+03   ! m/a -> mm/a
#endif

end do

20 close(10, status='keep')

ndata = n-1

!------------------------------------------------
! THIS IS JUST A HACK, SHOULD BE BLANKED OUT !!!
!
! write(42,'(a)') '#  t(a)  -  delT(C) - delV(m sle) - A(10**6km2) - Qfw(dSv)'
! write(42,'(a)') '# --------------------------------------------------------'
! do n=1, ndata
!    write(42,'(f8.1,f11.4,f13.4,f13.4,f12.4)') time(n)*1.0e+03, D_Ts(n), &
!         (V_tot(1)-V_tot(n))*7.2/2.85, A_ib(n), V_fw(n)*1.0e+04/YEAR_SEC
! end do
! stop ' Writing of extra time-series data to file fort.42 completed!'
!
! END OF HACK !!!
!------------------------------------------------

end subroutine read_ser

#if defined(HEINO)

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  r e a d _ s e d

!   Purpose    :  Reading of data of time-series files *.sed
!                 (for the sediment region of the HEINO set-up)

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine read_sed(runname, ndata)

use sicograph_variables

implicit none
integer n, ndata
character (len=256) :: runname
character ch_dummy

!-------- Name of time-series file --------

write(6,'(1x,a)') ' '
write(6,'(1x,a,a)') 'Name of time-series file: ', trim(runname)//'.sed'

!-------- Reading of data from time-series file --------

open(10, &
     file=OUTPATH//'/'//trim(runname)//'.sed', &
     status='old')

read(10,'(a)') ch_dummy
read(10,'(a)') ch_dummy
read(10,'(a)') ch_dummy

do n=1, 1000001

   read(10,*,end=20) time(n), D_Ts(n), z_sl(n)
   read(10,*,end=20) H_ave_sed(n), Tbh_ave_sed(n), Atb_sed(n)
   read(10,'(a)',end=20) ch_dummy

end do

20 close(10, status='keep')

ndata = n-1

end subroutine read_sed

#endif

#if ( defined(ANT) \
      || defined(EMTP2SGE) \
      || defined(GRL) \
      || defined(HEINO) \
      || defined(NMARS) )

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  r e a d _ c o r e

!   Purpose    :  Reading of data of time-series files *.core
!                 (for ice-core locations or selected points)

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine read_core(runname, ndata)

use sicograph_variables

implicit none
integer n, ndata
character (len=256) :: runname
character ch_dummy

!-------- Name of time-series file --------

write(6,'(1x,a)') ' '
write(6,'(1x,a,a)') 'Name of time-series file: ', trim(runname)//'.core'

!-------- Reading of data from time-series file --------

open(10, &
     file=OUTPATH//'/'//trim(runname)//'.core', &
     status='old')

do n=1, 6; read(10,'(a)') ch_dummy; end do

do n=1, 1000001

   read(10,*,end=20) time(n), D_Ts(n), z_sl(n)

#if defined(ANT)
   read(10,*,end=20)  H_Vo(n),  H_DA(n),  H_DC(n),  H_DF(n),  H_Ko(n),  H_By(n)
   read(10,*,end=20) vs_Vo(n), vs_DA(n), vs_DC(n), vs_DF(n), vs_Ko(n), vs_By(n)
   read(10,*,end=20) Tb_Vo(n), Tb_DA(n), Tb_DC(n), Tb_DF(n), Tb_Ko(n), Tb_By(n)
   read(10,*,end=20) Rb_Vo(n), Rb_DA(n), Rb_DC(n), Rb_DF(n), Rb_Ko(n), Rb_By(n)
#elif defined(EMTP2SGE)
   read(10,*,end=20)  H_P1(n),  H_P2(n)
   read(10,*,end=20) vs_P1(n), vs_P2(n)
   read(10,*,end=20) Tb_P1(n), Tb_P2(n)
   read(10,*,end=20) Rb_P1(n), Rb_P2(n)
#elif defined(GRL)
   read(10,*,end=20)  H_GR(n),  H_G2(n),  H_D3(n),  H_CC(n),  H_NG(n)
   read(10,*,end=20) vs_GR(n), vs_G2(n), vs_D3(n), vs_CC(n), vs_NG(n)
   read(10,*,end=20) Tb_GR(n), Tb_G2(n), Tb_D3(n), Tb_CC(n), Tb_NG(n)
   read(10,*,end=20) Rb_GR(n), Rb_G2(n), Rb_D3(n), Rb_CC(n), Rb_NG(n)
#elif defined(HEINO)
   read(10,*,end=20)  H_P1(n),  H_P2(n),  H_P3(n),  H_P4(n),  H_P5(n), &
                      H_P6(n),  H_P7(n)
   read(10,*,end=20) vs_P1(n), vs_P2(n), vs_P3(n), vs_P4(n), vs_P5(n), &
                     vs_P6(n), vs_P7(n)
   read(10,*,end=20) Tb_P1(n), Tb_P2(n), Tb_P3(n), Tb_P4(n), Tb_P5(n), &
                     Tb_P6(n), Tb_P7(n)
   read(10,*,end=20) Rb_P1(n), Rb_P2(n), Rb_P3(n), Rb_P4(n), Rb_P5(n), &
                     Rb_P6(n), Rb_P7(n)
#elif defined(NMARS)
   read(10,*,end=20)  H_NP(n),  H_C1(n),  H_C2(n)
   read(10,*,end=20) vs_NP(n), vs_C1(n), vs_C2(n)
   read(10,*,end=20) Tb_NP(n), Tb_C1(n), Tb_C2(n)
   read(10,*,end=20) Rb_NP(n), Rb_C1(n), Rb_C2(n)
#endif

   read(10,'(a)',end=20) ch_dummy

end do

20 close(10, status='keep')

ndata = n-1

#if ( defined(NMARS) )
   time  = time  * 1.0e-03   ! ka -> Ma
   vs_NP = vs_NP * 1.0e+03   ! m/a -> mm/a
   vs_C1 = vs_C1 * 1.0e+03   ! m/a -> mm/a
   vs_C2 = vs_C2 * 1.0e+03   ! m/a -> mm/a
#endif

end subroutine read_core

#endif

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

!   Subroutine :  r e a d _ d a t a

!   Purpose    :  Reading of the data for the plan-view data plots (present
!                 surface and bedrock topography, precipitation rate etc.).

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

subroutine read_data(domain, topo_marker, dx_int, menue)

use sicograph_variables

implicit none
integer :: i, j, m, n
integer :: ios
integer :: menue
integer :: n_month
real :: xi0_gr, eta0_gr
real, parameter :: eps=1.0e-05
character (len=256) :: inpath
character (len=256) :: filename
character (len= 16) :: domain, topo_marker, dx_int
character :: ch_dummy

!-------- Reading of topography data --------

#if defined(ZS_PRESENT_FILE)
filename = INPATH//'/'//trim(domain)//'/'//ZS_PRESENT_FILE
#else
filename = INPATH//'/'//trim(domain)//'/'//trim(domain)//trim(dx_int)//'_zs.dat'
#endif

open(21, iostat=ios, file=trim(filename), status='old')
if (ios.ne.0) stop ' Error when opening the zs file!'

#if defined(ZB_PRESENT_FILE)
filename = INPATH//'/'//trim(domain)//'/'//ZB_PRESENT_FILE
#else
filename = INPATH//'/'//trim(domain)//'/'//trim(domain)//trim(dx_int)//'_zb.dat'
#endif

open(22, iostat=ios, file=trim(filename), status='old')
if (ios.ne.0) stop ' Error when opening the zb file!'

#if defined(ZB0_FILE)
filename = INPATH//'/'//trim(domain)//'/'//ZB0_FILE
#else
filename = INPATH//'/'//trim(domain)//'/'//trim(domain)//trim(dx_int)//'_zb0.dat'
#endif

open(23, iostat=ios, file=trim(filename), status='old')
if (ios.ne.0) stop ' Error when opening the zb0 file!'

#if defined(MASK_PRESENT_FILE)
filename = INPATH//'/'//trim(domain)//'/'//MASK_PRESENT_FILE
#else
filename = INPATH//'/'//trim(domain)//'/'//trim(domain)//trim(dx_int)//'_mask.dat'
#endif

open(24, iostat=ios, file=trim(filename), status='old')
if (ios.ne.0) stop ' Error when opening the mask file!'

do m=1, 6; read(21,'(a)') ch_dummy; end do
do m=1, 6; read(22,'(a)') ch_dummy; end do
do m=1, 6; read(23,'(a)') ch_dummy; end do
do m=1, 6; read(24,'(a)') ch_dummy; end do

do j=JMAX, 0, -1
   read(21,*) (zs_gr(i,j), i=0,IMAX)
   read(22,*) (zb_gr(i,j), i=0,IMAX)
   read(23,*) (zb0_gr(i,j), i=0,IMAX)
   read(24,2300) (maske_gr(i,j), i=0,IMAX)
end do

close(21, status='keep')
close(22, status='keep')
close(23, status='keep')
close(24, status='keep')

2300 format(IMAX(i1),i1)

#if defined(ANT)

   zs_gr  = zs_gr  *1.0e-03   ! m -> km
   zb_gr  = zb_gr  *1.0e-03   ! m -> km
   zb0_gr = zb0_gr *1.0e-03   ! m -> km

#if ( defined(X0) && defined(Y0) )
   xi0_gr  = X0         ! Coordinates of the point
   eta0_gr = Y0         ! (i,j) = (0,0), in km
#else
   xi0_gr  = -2800.0    ! Coordinates of the point
   eta0_gr = -2400.0    ! (i,j) = (0,0), in km
#endif

#elif defined(EMTP2SGE)

   stop ' Reading of topography data not yet implemented!'

#elif defined(GRL)

   zs_gr  = zs_gr  *1.0e-03   ! m -> km
   zb_gr  = zb_gr  *1.0e-03   ! m -> km
   zb0_gr = zb0_gr *1.0e-03   ! m -> km

#if ( defined(X0) && defined(Y0) )
   xi0_gr  = X0         ! Coordinates of the point
   eta0_gr = Y0         ! (i,j) = (0,0), in km
#else
   xi0_gr  =  -720.0    ! Coordinates of the point
   eta0_gr = -3400.0    ! (i,j) = (0,0), in km
#endif

#elif defined(HEINO)

   stop ' Reading of topography data not yet implemented!'

#elif defined(NHEM)

   zs_gr  = zs_gr  *1.0e-03   ! m -> km
   zb_gr  = zb_gr  *1.0e-03   ! m -> km
   zb0_gr = zb0_gr *1.0e-03   ! m -> km

#if ( defined(X0) && defined(Y0) )
   xi0_gr  = X0         ! Coordinates of the point
   eta0_gr = Y0         ! (i,j) = (0,0), in km
#else
   xi0_gr  = -6240.0    ! Coordinates of the point
   eta0_gr = -6240.0    ! (i,j) = (0,0), in km
#endif

#elif defined(TIBET)

   zs_gr  = zs_gr  *1.0e-03   ! m -> km
   zb_gr  = zb_gr  *1.0e-03   ! m -> km
   zb0_gr = zb0_gr *1.0e-03   ! m -> km

   xi0_gr  = LAMBDA_0         ! Coordinates of the point
   eta0_gr = PHI_0            ! (i,j) = (0,0), in deg

#elif defined(NMARS)

#if ( defined(X0) && defined(Y0) )
   xi0_gr  = X0         ! Coordinates of the point
   eta0_gr = Y0         ! (i,j) = (0,0), in km
#else
   xi0_gr  =  -900.0    ! Coordinates of the point
   eta0_gr =  -900.0    ! (i,j) = (0,0), in km
#endif

#elif defined(SCAND)

   zs_gr  = zs_gr  *1.0e-03   ! m -> km
   zb_gr  = zb_gr  *1.0e-03   ! m -> km
   zb0_gr = zb0_gr *1.0e-03   ! m -> km

#if ( defined(X0) && defined(Y0) )
   xi0_gr  = X0         ! Coordinates of the point
   eta0_gr = Y0         ! (i,j) = (0,0), in km
#else
   xi0_gr  = -4670.0    ! Coordinates of the point
   eta0_gr = -3150.0    ! (i,j) = (0,0), in km
#endif

#elif defined(SMARS)

#if ( defined(X0) && defined(Y0) )
   xi0_gr  = X0         ! Coordinates of the point
   eta0_gr = Y0         ! (i,j) = (0,0), in km
#else
   xi0_gr  = -1200.0    ! Coordinates of the point
   eta0_gr = -1200.0    ! (i,j) = (0,0), in km
#endif

#endif

!-------- Reading of precipitation data --------

precip_gr = 0.0d0   ! dummy values

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(NHEM) \
      || defined(SCAND) \
      || defined(TIBET) )

if (menue == 15) then

#if ( defined(ANT) || defined(GRL) )
   filename = INPATH//'/'//trim(domain)//'/'//PRECIP_PRESENT_FILE
#elif ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' Month: (1) Jan, (2) Feb, ... , (12) Dec > '
   read (5,*) n_month
   filename = INPATH//'/'//trim(domain)//'/'//PRECIP_MM_PRESENT_FILE
#endif

   open(21, iostat=ios, file=trim(filename), status='old')
   if (ios /= 0) stop ' Error when opening the precip file!'

   do m=1, 6; read(21,'(a)') ch_dummy; end do

#if ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   do n=1, n_month-1
      do m=1, 3; read(21,'(a)') ch_dummy; end do
      do j=JMAX, 0, -1
         read(21,*) (precip_gr(i,j), i=0,IMAX)   ! dummies (wrong month)
      end do
   end do
   do m=1, 3; read(21,'(a)') ch_dummy; end do
#endif

   do j=JMAX, 0, -1
      read(21,*) (precip_gr(i,j), i=0,IMAX)
   end do

   close(21, status='keep')

end if

#endif

!-------- Reading of data for LGM anomaly of precipitation rate --------

precip_lgm_anom_gr = 0.0d0   ! dummy values

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(NHEM) \
      || defined(SCAND) \
      || defined(TIBET) )

if (menue == 16) then

#if ( defined(ANT) || defined(GRL) )
   filename = INPATH//'/'//trim(domain)//'/'//PRECIP_ANOM_FILE
#elif ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' Month: (1) Jan, (2) Feb, ... , (12) Dec > '
   read (5,*) n_month
   filename = INPATH//'/'//trim(domain)//'/'//PRECIP_MM_ANOM_FILE
#endif

   open(21, iostat=ios, file=trim(filename), status='old')
   if (ios /= 0) stop ' Error when opening the precip anom file!'

   do m=1, 6; read(21,'(a)') ch_dummy; end do

#if ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   do n=1, n_month-1
      do m=1, 3; read(21,'(a)') ch_dummy; end do
      do j=JMAX, 0, -1
         read(21,*) (precip_lgm_anom_gr(i,j), i=0,IMAX)   ! dummies (wrong month)
      end do
   end do
   do m=1, 3; read(21,'(a)') ch_dummy; end do
#endif

   do j=JMAX, 0, -1
      read(21,*) (precip_lgm_anom_gr(i,j), i=0,IMAX)
   end do

   close(21, status='keep')

#if ( defined(ANT) || defined(GRL) )
   precip_lgm_anom_gr = precip_lgm_anom_gr * PRECIP_ANOM_FACT
#elif ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   precip_lgm_anom_gr = precip_lgm_anom_gr * PRECIP_MM_ANOM_FACT
#endif

end if

#endif

!-------- Reading of data for the surface temperature --------

temp_s_gr = 0.0d0   ! dummy values

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(NHEM) \
      || defined(SCAND) \
      || defined(TIBET) )

if (menue == 17) then

#if defined(ANT)

   inpath = '/uchi/greve/Documents/sico_data/ant_temp_huybrechts'

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' (1) mean annual, (2) mean January > '
   read (5,*) n_month
   if (n_month == 1) then
      filename = trim(inpath)//'/'//trim(domain)//trim(dx_int)//'_temp_ma.dat'
   else if (n_month == 2) then
      filename = trim(inpath)//'/'//trim(domain)//trim(dx_int)//'_temp_mj.dat'
   end if

#elif defined(GRL)

   inpath = '/uchi/greve/Documents/sico_data/grl_temp_ritz'

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' (1) mean annual, (2) mean July > '
   read (5,*) n_month
   if (n_month == 1) then
      filename = trim(inpath)//'/'//trim(domain)//trim(dx_int)//'_temp_ma.dat'
   else if (n_month == 2) then
      filename = trim(inpath)//'/'//trim(domain)//trim(dx_int)//'_temp_mj.dat'
   end if

#elif ( defined(NHEM) || defined(SCAND) || defined(TIBET) )

   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' Month: (1) Jan, (2) Feb, ... , (12) Dec > '
   read (5,*) n_month
   filename = INPATH//'/'//trim(domain)//'/'//TEMP_MM_PRESENT_FILE

#endif

   open(21, iostat=ios, file=trim(filename), status='old')
   if (ios /= 0) stop ' Error when opening the temp_s file!'

   do m=1, 6; read(21,'(a)') ch_dummy; end do

#if ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   do n=1, n_month-1
      do m=1, 3; read(21,'(a)') ch_dummy; end do
      do j=JMAX, 0, -1
         read(21,*) (temp_s_gr(i,j), i=0,IMAX)   ! dummies (wrong month)
      end do
   end do
   do m=1, 3; read(21,'(a)') ch_dummy; end do
#endif

   do j=JMAX, 0, -1
      read(21,*) (temp_s_gr(i,j), i=0,IMAX)
   end do

   close(21, status='keep')

end if

#endif

!-------- Reading of data for LGM anomaly of surface temperature --------

temp_s_lgm_anom_gr = 0.0d0   ! dummy values

#if ( defined(ANT) \
      || defined(GRL) \
      || defined(NHEM) \
      || defined(SCAND) \
      || defined(TIBET) )

if (menue == 18) then

#if defined(ANT)
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' (1) mean annual, (2) mean January > '
   read (5,*) n_month
   if (n_month == 1) then
      filename = INPATH//'/'//trim(domain)//'/'//TEMP_MA_ANOM_FILE
   else if (n_month == 2) then
      filename = INPATH//'/'//trim(domain)//'/'//TEMP_MJ_ANOM_FILE
   end if
#elif defined(GRL)
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' (1) mean annual, (2) mean July > '
   read (5,*) n_month
   if (n_month == 1) then
      filename = INPATH//'/'//trim(domain)//'/'//TEMP_MA_ANOM_FILE
   else if (n_month == 2) then
      filename = INPATH//'/'//trim(domain)//'/'//TEMP_MJ_ANOM_FILE
   end if
#elif ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   write(6,'(1x,a)') ' '
   write(6,'(1x,a)',advance='no') ' Month: (1) Jan, (2) Feb, ... , (12) Dec > '
   read (5,*) n_month
   filename = INPATH//'/'//trim(domain)//'/'//TEMP_MM_ANOM_FILE
#endif

   open(21, iostat=ios, file=trim(filename), status='old')
   if (ios /= 0) stop ' Error when opening the temp_s anom file!'

   do m=1, 6; read(21,'(a)') ch_dummy; end do

#if ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   do n=1, n_month-1
      do m=1, 3; read(21,'(a)') ch_dummy; end do
      do j=JMAX, 0, -1
         read(21,*) (temp_s_lgm_anom_gr(i,j), i=0,IMAX)   ! dummies (wrong month)
      end do
   end do
   do m=1, 3; read(21,'(a)') ch_dummy; end do
#endif

   do j=JMAX, 0, -1
      read(21,*) (temp_s_lgm_anom_gr(i,j), i=0,IMAX)
   end do

   close(21, status='keep')

#if ( defined(ANT) || defined(GRL) )
   if (n_month == 1) then
      temp_s_lgm_anom_gr = temp_s_lgm_anom_gr * TEMP_MA_ANOM_FACT
   else if (n_month == 2) then
      temp_s_lgm_anom_gr = temp_s_lgm_anom_gr * TEMP_MJ_ANOM_FACT
   end if
#elif ( defined(NHEM) || defined(SCAND) || defined(TIBET) )
   temp_s_lgm_anom_gr = temp_s_lgm_anom_gr * TEMP_MM_ANOM_FACT
#endif

end if

#endif

!-------- Reading of geothermal-heat-flux data --------

qgeo_gr = 0.0d0   ! dummy values

#if ( defined(ANT) || defined(GRL) || defined(NMARS) )

if (menue == 19) then

   filename = INPATH//'/'//trim(domain)//'/'//Q_GEO_FILE

   open(21, iostat=ios, file=trim(filename), status='old')
   if (ios /= 0) stop ' Error when opening the qgeo file!'

   do m=1, 6; read(21,'(a)') ch_dummy; end do

   do j=JMAX, 0, -1
      read(21,*) (qgeo_gr(i,j), i=0,IMAX)
   end do

   close(21, status='keep')

end if

#endif

!-------- Reading of surface-velocity data --------

v_s_gr = 0.0d0   ! dummy values

#if ( defined(GRL) )

if (menue == 20) then

   inpath   = '/uchi/greve/Documents/sico_data/grl_negis_velocity_parca'
   filename = trim(inpath)//'/'//trim(domain)//trim(dx_int) &
              //'_parca_negis_vs.dat'

   open(21, iostat=ios, file=trim(filename), status='old')
   if (ios /= 0) stop ' Error when opening the vs file!'

   do m=1, 6; read(21,'(a)') ch_dummy; end do

   do j=JMAX, 0, -1
      read(21,*) (v_s_gr(i,j), i=0,IMAX)
   end do

   close(21, status='keep')

end if

#endif

!-------- Gridpoints on the x and y axis --------

#if ( (GRID==0) || (GRID==1) )

do i=0, IMAX
   xi_gr(i)  = xi0_gr+real(i)*DX
end do

do j=0, JMAX
   eta_gr(j) = eta0_gr+real(j)*DX
end do

#elif (GRID==2)

do i=0, IMAX
   xi_gr(i)  = xi0_gr+real(i)*DLAMBDA
end do

do j=0, JMAX
   eta_gr(j) = eta0_gr+real(j)*DPHI
end do

#endif

!-------- Ice thickness --------

do i=0, IMAX
do j=0, JMAX
   if (maske_gr(i,j) == 0) then
      H_c_gr(i,j) = zs_gr(i,j)-zb_gr(i,j)
      H_t_gr(i,j) = 0.0
   else
      H_c_gr(i,j) = 0.0
      H_t_gr(i,j) = 0.0
   end if
end do
end do

end subroutine read_data

!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
!                           End of sicograph.F90
!+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
